pub struct HttpClient(/* private fields */);Expand description
A struct to execute requests to the Revolt REST API.
Implementations
Sourceimpl HttpClient
impl HttpClient
Sourcepub async fn get<T: DeserializeOwned>(&self, path: impl AsRef<str>) -> Result<T>
pub async fn get<T: DeserializeOwned>(&self, path: impl AsRef<str>) -> Result<T>
Make a GET request to the API and convert the response body to json.
Sourcepub async fn post<T: DeserializeOwned, U: Serialize>(
&self,
path: impl AsRef<str>,
body: U,
) -> Result<T>
pub async fn post<T: DeserializeOwned, U: Serialize>( &self, path: impl AsRef<str>, body: U, ) -> Result<T>
Make a POST request to the API with a json body and convert the response body to json.
Sourcepub async fn put<T: Serialize>(&self, path: impl AsRef<str>, body: T) -> Result
pub async fn put<T: Serialize>(&self, path: impl AsRef<str>, body: T) -> Result
Make a PUT request to the API with a json body.